CollapseGraphPairCombinator
===========================

.. currentmodule:: pykeen.datasets.ea.combination

.. autoclass:: CollapseGraphPairCombinator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CollapseGraphPairCombinator.process

   .. rubric:: Methods Documentation

   .. automethod:: process
